# jokes command methods

def help(*args):
	""" Info about commands """
	helpstr = '--------------------------------\n \
\
List of Shell Commands:\n\n \
help :) show list of commands\n \
joke :) show metainfo\n \
exit :) exit the shell\
\
\n\njokes built-in statements: \
\
\n--------------------------------'
	
	return helpstr

def joke(*args):
	return 'this is a funny joke version 0.00'

# class jokes():
# 	def output(self, *args):
# 		return args
# 		
# 	def input(self):
# 		return input()
# 	
# 	def call(self, *args):
# 		vals = []
# 		for arg in args:
# 			vals.append( arg() )
# 		return vals


# jokes parser
from jokes.modules import cmd

class stream():
	__stream = []
	
	def push(self, uin):
		self.__stream.append(uin)
		return uin

def read_words(*words):
	for word in words:
		print(word)
	return words

def parse(uin):
	""" Parses input string uin and returns the return value """	
	#print( uin.split() ) #Debug
	
	words = uin.split()
	try:
		return getattr(cmd, words[0])( *words[1:] )
	except AttributeError:
		return read_words(*words )
		return 'no such command'
		
	return None


from distutils.core import setup
VERSION = '0.1.6'
setup(
  name = 'jokes',
  packages = ['jokes',
              'jokes.modules',
              'jokes.core',],
  package_data = {'jokes':['scripts/*']},
  scripts = ['jokes/scripts/jokes',],
  version = VERSION,
  description = 'Experimental language written in python',
  author = 'Kumseok Jung',
  author_email = 'jungkumseok@gmail.com',
  license = 'LICENSE',
  url = 'https://github.com/jungkumseok/jokes',
  download_url = 'https://github.com/jungkumseok/jokes/archive/'+VERSION+'.tar.gz',
  keywords = ['testing', 'language'], 
  classifiers = [],
)
